@@ -31,11 +31,13 @@
 #include "codec_def_common_encode.h"
 #include "codec_def_common_vp9.h"
 
+#define CODECHAL_ENCODE_VP9_MAX_NAL_UNIT_TYPE       1 // only support one NAL unit for uncompressed header
 #define CODECHAL_ENCODE_VP9_MAX_NUM_TEMPORAL_LAYERS 8
 #define ENCODE_VP9_NUM_MAX_L0_REF                   3
 #define VP9_MAX_COEFF_PARTITIONS                    4
 #define VP9_HYBRIDPAK_PER_MB_DATA_SIZE              816
 #define VP9_HYBRIDPAK_PER_MB_MV_DATA_SIZE           64
+#define CODECHAL_ENCODE_VP9_FRAME_HEADER_SIZE       4096
 
 typedef enum
 {
