@@ -61,6 +61,12 @@ inline static bool CodechalDecodeResolutionEqualLargerThan5k(uint32_t width, uin
         || ((width >= CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD3_WIDTH) && (height >= CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD1_HEIGHT)));
 }
 
+inline static bool CodechalDecodeResolutionEqualLargerThan8k(uint32_t width, uint32_t height)
+{
+    return (((width * height) >= (CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD4_WIDTH * CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD4_HEIGHT)) 
+        || ((width >= CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD4_WIDTH) && (height >= CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD4_HEIGHT)));
+}
+
 inline static bool CodechalDecodeNonRextFormat(MOS_FORMAT format)
 {
     return ((format == Format_NV12) || (format == Format_P010));
@@ -110,6 +116,7 @@ typedef struct _CODECHAL_DECODE_SCALABILITY_INIT_PARAMS
     uint8_t          u8NumTileRows;                  //!< Number of tile rows for this picture
     MOS_GPU_CONTEXT  gpuCtxInUse;                    //!< gpu context in use
     bool             usingSecureDecode;
+    bool             usingHistogram;
 }CODECHAL_DECODE_SCALABILITY_INIT_PARAMS, *PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS;
 
 typedef struct _CODECHAL_DECODE_SCALABILITY_STATE CODECHAL_DECODE_SCALABILITY_STATE, *PCODECHAL_DECODE_SCALABILITY_STATE;
