@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2021, Intel Corporation
+* Copyright (c) 2009-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -33,46 +33,18 @@
 #include "mhw_vebox.h"
 #include "mhw_sfc.h"
 #include "vp_pipeline_adapter_base.h"
-#include "vp_feature_report.h"
-
-//*-----------------------------------------------------------------------------
-//| DEFINITIONS
-//*-----------------------------------------------------------------------------
-// Incremental size for allocating/reallocating resource
-#define VPHAL_BUFFER_SIZE_INCREMENT     128
+#include "vphal_common_hdr.h"
+#include "vp_common.h"
+#include "vp_base.h"
+#include "renderhal_legacy.h"
 
 // YUV input ranges
-#define YUV_RANGE_16_235                1
-#define YUV_RANGE_0_255                 2
 #define YUV_RANGE_FROM_DDI              3
 
 // RGB input ranges
 #define RGB_RANGE_16_235                1
 #define RGB_RANGE_0_255                 0
 
-// Media Features width
-#define VPHAL_RNDR_8K_WIDTH (7680)
-#define VPHAL_RNDR_16K_HEIGHT_LIMIT (16352)
-
-// Media Features height
-#define VPHAL_RNDR_2K_HEIGHT  1080
-// The reason that the definition is not (VPHAL_RNDR_2K_HEIGHT*2) is because some 4K clips have 1200 height.
-#define VPHAL_RNDR_4K_HEIGHT  1200
-#define VPHAL_RNDR_4K_MAX_HEIGHT  3112
-#define VPHAL_RNDR_4K_MAX_WIDTH  4096
-#define VPHAL_RNDR_6K_HEIGHT  (VPHAL_RNDR_2K_HEIGHT*3)
-#define VPHAL_RNDR_8K_HEIGHT  (VPHAL_RNDR_2K_HEIGHT*4)
-#define VPHAL_RNDR_10K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*5)
-#define VPHAL_RNDR_12K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*6)
-#define VPHAL_RNDR_14K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*7)
-#define VPHAL_RNDR_16K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*8)
-#define VPHAL_RNDR_18K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*9)
-#define VPHAL_RNDR_20K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*10)
-#define VPHAL_RNDR_22K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*11)
-#define VPHAL_RNDR_24K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*12)
-#define VPHAL_RNDR_26K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*13)
-#define VPHAL_RNDR_28K_HEIGHT (VPHAL_RNDR_2K_HEIGHT*14)
-
 //------------------------------------------------------------------------------
 // Simplified macros for debug message, Assert, Null check and MOS eStatus check
 // within VPhal without the need to explicitly pass comp and sub-comp name
@@ -87,6 +59,9 @@
 #define VPHAL_HW_ASSERTMESSAGE(_message, ...)                                        \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
+#define VPHAL_HW_WARNINGMESSAGE(_message, ...)                                       \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_HW, _message, ##__VA_ARGS__)
+
 #define VPHAL_HW_NORMALMESSAGE(_message, ...)                                        \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
@@ -114,6 +89,9 @@
 #define VPHAL_PUBLIC_ASSERTMESSAGE(_message, ...)                                    \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
 
+#define VPHAL_PUBLIC_WARNINGMESSAGE(_message, ...)                                   \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
+
 #define VPHAL_PUBLIC_NORMALMESSAGE(_message, ...)                                    \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
 
@@ -147,6 +125,9 @@
 #define VPHAL_DEBUG_ASSERTMESSAGE(_message, ...)                                     \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
+#define VPHAL_DEBUG_WARNINGMESSAGE(_message, ...)                                    \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
+
 #define VPHAL_DEBUG_NORMALMESSAGE(_message, ...)                                     \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
@@ -177,6 +158,9 @@
 #define VPHAL_RENDER_ASSERTMESSAGE(_message, ...)                                    \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_RENDER, _message, ##__VA_ARGS__)
 
+#define VPHAL_RENDER_WARNINGMESSAGE(_message, ...)                                   \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_RENDER, _message, ##__VA_ARGS__)
+
 #define VPHAL_RENDER_NORMALMESSAGE(_message, ...)                                    \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_RENDER, _message, ##__VA_ARGS__)
 
@@ -225,6 +209,9 @@
 #define VP_DDI_NORMALMESSAGE(_message, ...)                                          \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DDI, _message, ##__VA_ARGS__)
 
+#define VP_DDI_WARNINGMESSAGE(_message, ...)                                         \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DDI, _message, ##__VA_ARGS__)
+
 #define VP_DDI_VERBOSEMESSAGE(_message, ...)                                         \
     MOS_VERBOSEMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DDI, _message, ##__VA_ARGS__)
 
@@ -249,33 +236,6 @@
 #define VPHAL_DDI_CHK_NULL_WITH_HR(_ptr)                                             \
     MOS_CHK_NULL_WITH_HR(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DDI, _ptr)
 
-//!
-//! \brief Base VP kernel list
-//!
-enum VpKernelID
-{
-    // FC
-    kernelCombinedFc = 0,
-
-    // 2 VEBOX KERNELS
-    kernelVeboxSecureBlockCopy,
-    kernelVeboxUpdateDnState,
-
-    // User Ptr
-    kernelUserPtr,
-    // Fast 1toN
-    kernelFast1toN,
-
-    // HDR
-    kernelHdrMandatory,
-    kernelHdrPreprocess,
-
-    // mediacopy-render copy
-    kernelRenderCopy,
-
-    baseKernelMaxNumID
-};
-
 //!
 //! \brief VPHAL SS/EU setting
 //!
@@ -311,12 +271,6 @@ using VphalSettings =  VpSettings;
 #pragma pack(push)
 #pragma pack(1)
 
-//!
-//! Structure VphalFeatureReport
-//! \brief    Vphal Feature Report Structure
-//!
-using VphalFeatureReport = VpFeatureReport;
-
 #pragma pack(pop)
 
 
@@ -324,9 +278,12 @@ using VphalFeatureReport = VpFeatureReport;
 //! Class VphalState
 //! \brief VPHAL class definition
 //!
-class VphalState
+class VphalState : public VpBase
 {
 public:
+    // Perf Optimize for ClearVideoView DDI
+    bool m_clearVideoViewMode = false;
+
     // factory function
     static VphalState* VphalStateFactory(
         PMOS_INTERFACE          pOsInterface,
@@ -347,7 +304,6 @@ public:
     //!
     VphalState(
         PMOS_INTERFACE          pOsInterface,
-        PMOS_CONTEXT            pOsDriverContext,
         MOS_STATUS              *peStatus);
 
     //!
@@ -377,7 +333,7 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS Allocate(
-        const VphalSettings     *pVpHalSettings);
+        const VphalSettings *pVpHalSettings) override;
 
     //!
     //! \brief    Performs VP Rendering
@@ -389,7 +345,7 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS Render(
-        PCVPHAL_RENDER_PARAMS   pcRenderParams);
+        PCVPHAL_RENDER_PARAMS pcRenderParams) override;
 
     //!
     //! \brief    Get feature reporting from renderer
@@ -397,7 +353,7 @@ public:
     //! \return   VphalFeatureReport*
     //!           Pointer to VPHAL_FEATURE_REPOR: rendering features reported
     //!
-    virtual VphalFeatureReport*       GetRenderFeatureReport();
+    virtual VphalFeatureReport*       GetRenderFeatureReport() override;
 
     //!
     //! \brief    Get Status Report
@@ -410,7 +366,7 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     virtual MOS_STATUS GetStatusReport(
         PQUERY_STATUS_REPORT_APP        pQueryReport,
-        uint16_t                        numStatus);
+        uint16_t                 numStatus) override;
 
     //!
     //! \brief    Get Status Report's entry length from head to tail
@@ -420,15 +376,15 @@ public:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
-    MOS_STATUS GetStatusReportEntryLength(
-        uint32_t                         *puiLength);
+    virtual MOS_STATUS GetStatusReportEntryLength(
+        uint32_t                         *puiLength) override;
 
-    PLATFORM &GetPlatform()
+    virtual PLATFORM &GetPlatform() override
     {
         return m_platform;
     }
 
-    MEDIA_FEATURE_TABLE* GetSkuTable()
+    virtual MEDIA_FEATURE_TABLE *GetSkuTable() override
     {
         return m_skuTable;
     }
@@ -438,12 +394,12 @@ public:
         return m_waTable;
     }
 
-    PMOS_INTERFACE GetOsInterface()
+    virtual PMOS_INTERFACE GetOsInterface() override
     {
         return m_osInterface;
     }
 
-    PRENDERHAL_INTERFACE GetRenderHal()
+    virtual PRENDERHAL_INTERFACE GetRenderHal() override
     {
         return m_renderHal;
     }
@@ -482,7 +438,19 @@ public:
 
         if (m_veboxInterface != nullptr)
         {
-            MOS_STATUS eStatus = m_veboxInterface->DestroyHeap();
+            m_veboxItf = std::static_pointer_cast<mhw::vebox::Itf>(m_veboxInterface->GetNewVeboxInterface());
+            MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+            if (m_veboxItf)
+            {
+                eStatus = m_veboxItf->DestroyHeap();
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    VPHAL_PUBLIC_ASSERTMESSAGE("Failed to destroy Vebox Interface, eStatus:%d.\n", eStatus);
+                }
+            }
+
+            eStatus = m_veboxInterface->DestroyHeap();
             MOS_Delete(m_veboxInterface);
             m_veboxInterface = nullptr;
             if (eStatus != MOS_STATUS_SUCCESS)
@@ -492,6 +460,7 @@ public:
         }
 
         m_veboxInterface = veboxInterface;
+        m_veboxItf = std::static_pointer_cast<mhw::vebox::Itf>(veboxInterface->GetNewVeboxInterface());
     }
 
     void SetMhwSfcInterface(MhwSfcInterface* sfcInterface)
@@ -513,8 +482,6 @@ public:
     virtual MOS_STATUS GetVpMhwInterface(
         VP_MHWINTERFACE &vpMhwinterface);
 
-    HANDLE                      m_gpuAppTaskEvent;
-
 protected:
     // Internals
     PLATFORM                    m_platform;
@@ -523,11 +490,12 @@ protected:
 
     // States
     PMOS_INTERFACE              m_osInterface;
-    PRENDERHAL_INTERFACE        m_renderHal;
+    PRENDERHAL_INTERFACE_LEGACY m_renderHal;
     PMHW_VEBOX_INTERFACE        m_veboxInterface;
     MhwCpInterface              *m_cpInterface;
     PMHW_SFC_INTERFACE          m_sfcInterface;
     VphalRenderer               *m_renderer;
+    std::shared_ptr<mhw::vebox::Itf> m_veboxItf = nullptr;
 
     // Render GPU context/node
     MOS_GPU_NODE                m_renderGpuNode;
@@ -536,6 +504,7 @@ protected:
     // StatusTable indicating if command is done by gpu or not
     VPHAL_STATUS_TABLE          m_statusTable = {};
 
+    MediaUserSettingSharedPtr   m_userSettingPtr = nullptr;  //!< usersettingInstance
 
     // Same MOS_GPU_CONTEXT may be created in MediaContext with a different handle,
     // which will cause the gpuContext created in VphalState missed to be destroyed during
@@ -551,7 +520,12 @@ protected:
     //!
     virtual MOS_STATUS CreateRenderer() = 0;
 
-    virtual bool IsApoEnabled()
+    virtual bool IsApoEnabled() override
+    {
+        return false;
+    }
+
+    virtual bool IsRenderContextBasedSchedulingNeeded()
     {
         return false;
     }
@@ -576,6 +550,16 @@ private:
     //!
     MOS_STATUS DestroyGpuContextWithInvalidHandle();
 
+    //!
+    //! \brief    Check whether GPU context is reused or not
+    //! \details  Check whether GPU context is reused or not
+    //! \param    MOS_GPU_CONTEXT mosGpuConext
+    //!           [in] Mos GPU context
+    //! \return   bool
+    //!           Return true if is reused, otherwise false
+    //!
+    bool IsGpuContextReused(
+        MOS_GPU_CONTEXT mosGpuContext);
 };
 
 #endif  // __VPHAL_H__
