@@ -28,7 +28,7 @@
 
 #include "mhw_vebox_generic.h"
 #include "mhw_vebox_hwcmd_g12_X.h"
-#include "renderhal.h"
+#include "renderhal_legacy.h"
 
 #define MHW_VEBOX_TIMESTAMP_PER_TICK_IN_NS_G12              83.333f
 
@@ -78,8 +78,7 @@ const MHW_VEBOX_SETTINGS g_Vebox_Settings_g12 =
     MHW_PAGE_SIZE,                                                            //!< uiVertexTableSize
     MHW_PAGE_SIZE,                                                            //!< uiCapturePipeStateSize
     MHW_PAGE_SIZE * 2,                                                        //!< uiGammaCorrectionStateSize
-    0,                                                                        //!< ui3DLUTSize
-    0                                                                         //!< uiHdrStateSize
+    MHW_PAGE_SIZE * 18,                                                       //!< uiHdrStateSize
 };
 
 class MhwVeboxInterfaceG12 : public MhwVeboxInterfaceGeneric<mhw_vebox_g12_X>
@@ -128,6 +127,9 @@ public:
         PMHW_VEBOX_IECP_PARAMS  pVeboxIecpParams,
         PMHW_VEBOX_GAMUT_PARAMS pVeboxGamutParams);
 
+    MOS_STATUS AddVeboxHdrState(
+        PMHW_VEBOX_IECP_PARAMS pVeboxIecpParams);
+
     MOS_STATUS FindVeboxGpuNodeToUse(
         PMHW_VEBOX_GPUNODE_LIMIT pGpuNodeLimit);
 
@@ -147,7 +149,7 @@ public:
 
         MhwVeboxInterfaceGeneric<mhw_vebox_g12_X>::SetVeboxIecpStateSTE(pVeboxStdSteState, pColorPipeParams);
         // Enable Skin Score Output surface to be written by Vebox
-        pVeboxStdSteState->DW1.StdScoreOutput = pColorPipeParams->bEnableLACE && pColorPipeParams->LaceParams.bSTD;
+        pVeboxStdSteState->DW1.StdScoreOutput = (pColorPipeParams->bEnableLACE && pColorPipeParams->LaceParams.bSTD) || pColorPipeParams->bEnableSTD;
 
     finish:
         return eStatus;
@@ -334,6 +336,7 @@ private:
     MOS_STATUS ValidateVeboxScalabilityConfig();
 #endif
 
+protected:
     void SetVeboxSurfaces(
         PMHW_VEBOX_SURFACE_PARAMS                 pSurfaceParam,
         PMHW_VEBOX_SURFACE_PARAMS                 pDerivedSurfaceParam,
