@@ -19,18 +19,16 @@
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
-
 #include "MDF_FC_common_genx.h"
 
-_GENX_MAIN_ void Y410_444Scale16_Buf_4_Rot_180(
+_GENX_MAIN_ void Y210_444Scale16_Buf_4_Rot_180(
     CURBE_INPUT_OUTPUT,
     GLOBAL_BUFFER_INPUT_OUTPUT)
 {
-#define Y410_SUPPORT
+
 #define BUFFER_4
 #define ROTATE_180
-#include "PA_Scale_Buf.h"
+#include "Y210_Scale_Buf.h"
 #undef ROTATE_180
 #undef BUFFER_4
-#undef Y410_SUPPORT
 }
\ No newline at end of file
