@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -105,7 +105,7 @@ protected:
     //!
     //! \brief  Constructor
     //!
-    MhwVdboxMfxInterfaceG8<TMfxCmds>(
+    MhwVdboxMfxInterfaceG8(
         PMOS_INTERFACE osInterface,
         MhwMiInterface *miInterface,
         MhwCpInterface *cpInterface,
@@ -157,6 +157,10 @@ protected:
         mmioRegisters->generalPurposeRegister0HiOffset            = GENERAL_PURPOSE_REGISTER0_HI_OFFSET_NODE_1_INIT_G8;
         mmioRegisters->generalPurposeRegister4LoOffset            = GENERAL_PURPOSE_REGISTER4_LO_OFFSET_NODE_1_INIT_G8;
         mmioRegisters->generalPurposeRegister4HiOffset            = GENERAL_PURPOSE_REGISTER4_HI_OFFSET_NODE_1_INIT_G8;
+        mmioRegisters->generalPurposeRegister11LoOffset           = GENERAL_PURPOSE_REGISTER11_LO_OFFSET_NODE_1_INIT_G8;
+        mmioRegisters->generalPurposeRegister11HiOffset           = GENERAL_PURPOSE_REGISTER11_HI_OFFSET_NODE_1_INIT_G8;
+        mmioRegisters->generalPurposeRegister12LoOffset           = GENERAL_PURPOSE_REGISTER12_LO_OFFSET_NODE_1_INIT_G8;
+        mmioRegisters->generalPurposeRegister12HiOffset           = GENERAL_PURPOSE_REGISTER12_HI_OFFSET_NODE_1_INIT_G8;
         mmioRegisters->mfcImageStatusMaskRegOffset                = MFC_IMAGE_STATUS_MASK_REG_OFFSET_NODE_1_INIT_G8;
         mmioRegisters->mfcImageStatusCtrlRegOffset                = MFC_IMAGE_STATUS_CTRL_REG_OFFSET_NODE_1_INIT_G8;
         mmioRegisters->mfcAvcNumSlicesRegOffset                   = MFC_AVC_NUM_SLICES_REG_OFFSET_NODE_1_INIT_G8;
@@ -187,6 +191,10 @@ protected:
         mmioRegisters->generalPurposeRegister0HiOffset            = GENERAL_PURPOSE_REGISTER0_HI_OFFSET_NODE_2_INIT_G8;
         mmioRegisters->generalPurposeRegister4LoOffset            = GENERAL_PURPOSE_REGISTER4_LO_OFFSET_NODE_2_INIT_G8;
         mmioRegisters->generalPurposeRegister4HiOffset            = GENERAL_PURPOSE_REGISTER4_HI_OFFSET_NODE_2_INIT_G8;
+        mmioRegisters->generalPurposeRegister11LoOffset           = GENERAL_PURPOSE_REGISTER11_LO_OFFSET_NODE_2_INIT_G8;
+        mmioRegisters->generalPurposeRegister11HiOffset           = GENERAL_PURPOSE_REGISTER11_HI_OFFSET_NODE_2_INIT_G8;
+        mmioRegisters->generalPurposeRegister12LoOffset           = GENERAL_PURPOSE_REGISTER12_LO_OFFSET_NODE_2_INIT_G8;
+        mmioRegisters->generalPurposeRegister12HiOffset           = GENERAL_PURPOSE_REGISTER12_HI_OFFSET_NODE_2_INIT_G8;
         mmioRegisters->mfcImageStatusMaskRegOffset                = MFC_IMAGE_STATUS_MASK_REG_OFFSET_NODE_2_INIT_G8;
         mmioRegisters->mfcImageStatusCtrlRegOffset                = MFC_IMAGE_STATUS_CTRL_REG_OFFSET_NODE_2_INIT_G8;
         mmioRegisters->mfcAvcNumSlicesRegOffset                   = MFC_AVC_NUM_SLICES_REG_OFFSET_NODE_2_INIT_G8;
@@ -296,18 +304,20 @@ protected:
             {
                 maxSize +=
                     mhw_mi_g8_X::MI_CONDITIONAL_BATCH_BUFFER_END_CMD::byteSize +
-                    mhw_mi_g8_X::MI_FLUSH_DW_CMD::byteSize * 3 +   // 3 extra MI_FLUSH_DWs for encode
-                    TMfxCmds::MFX_FQM_STATE_CMD::byteSize * 4 +   // FQM_State sent 4 times
-                    mhw_mi_g8_X::MI_STORE_REGISTER_MEM_CMD::byteSize * 8 +   // 5 extra register queries for encode, 3 extra slice level commands for BrcPakStatistics
-                    mhw_mi_g8_X::MI_STORE_DATA_IMM_CMD::byteSize * 3 + // slice level commands for StatusReport, BrcPakStatistics
-                    MHW_VDBOX_PAK_BITSTREAM_OVERFLOW_SIZE;                   // accounting for the max DW payload for PAK_INSERT_OBJECT, for frame header payload
+                    mhw_mi_g8_X::MI_FLUSH_DW_CMD::byteSize * 3 +           // 3 extra MI_FLUSH_DWs for encode
+                    TMfxCmds::MFX_FQM_STATE_CMD::byteSize * 4 +            // FQM_State sent 4 times
+                    mhw_mi_g8_X::MI_STORE_REGISTER_MEM_CMD::byteSize * 8 + // 5 extra register queries for encode, 3 extra slice level commands for BrcPakStatistics
+                    mhw_mi_g8_X::MI_STORE_DATA_IMM_CMD::byteSize * 3 +     // slice level commands for StatusReport, BrcPakStatistics
+                    MHW_VDBOX_PAK_BITSTREAM_OVERFLOW_SIZE +                // accounting for the max DW payload for PAK_INSERT_OBJECT, for frame header payload
+                    TMfxCmds::MFX_PAK_INSERT_OBJECT_CMD::byteSize * 4;     // for inserting AU, SPS, PSP, SEI headers before first slice header
 
                 patchListMaxSize +=
                     PATCH_LIST_COMMAND(MI_CONDITIONAL_BATCH_BUFFER_END_CMD) +
                     (PATCH_LIST_COMMAND(MI_FLUSH_DW_CMD) * 3) +
                     (PATCH_LIST_COMMAND(MFX_FQM_STATE_CMD) * 4) +
-                    (PATCH_LIST_COMMAND(MI_STORE_REGISTER_MEM_CMD) * 8) + // 3 extra slice level commands for BrcPakStatistics
-                    PATCH_LIST_COMMAND(MI_STORE_DATA_IMM_CMD) * 3;// slice level commands for StatusReport, BrcPakStatistics
+                    (PATCH_LIST_COMMAND(MI_STORE_REGISTER_MEM_CMD) * 8) +    // 3 extra slice level commands for BrcPakStatistics
+                    (PATCH_LIST_COMMAND(MI_STORE_DATA_IMM_CMD) * 3) +        // slice level commands for StatusReport, BrcPakStatistics
+                    (PATCH_LIST_COMMAND(MFC_AVC_PAK_INSERT_OBJECT_CMD) * 4);
             }
             else
             {
@@ -474,24 +484,27 @@ protected:
                 if (isModeSpecific)
                 {
                     // isModeSpecific = bSingleTaskPhaseSupported for AVC encode
-                    maxSize += 2 * mhw_mi_g8_X::MI_BATCH_BUFFER_START_CMD::byteSize;
+                    maxSize += (2 * mhw_mi_g8_X::MI_BATCH_BUFFER_START_CMD::byteSize);
                     patchListMaxSize += (2 * PATCH_LIST_COMMAND(MI_BATCH_BUFFER_START_CMD));
                 }
                 else
                 {
                     maxSize +=
-                        TMfxCmds::MFX_AVC_SLICE_STATE_CMD::byteSize +
                         (2 * TMfxCmds::MFX_AVC_REF_IDX_STATE_CMD::byteSize) +
                         (2 * TMfxCmds::MFX_AVC_WEIGHTOFFSET_STATE_CMD::byteSize) +
-                        TMfxCmds::MFX_PAK_INSERT_OBJECT_CMD::byteSize +
-                        MHW_VDBOX_PAK_BITSTREAM_OVERFLOW_SIZE + // slice header payload
-                        mhw_mi_g8_X::MI_BATCH_BUFFER_END_CMD::byteSize;
+                        TMfxCmds::MFX_AVC_SLICE_STATE_CMD::byteSize +
+                        MHW_VDBOX_PAK_SLICE_HEADER_OVERFLOW_SIZE + // slice header payload
+                        (2 * TMfxCmds::MFX_PAK_INSERT_OBJECT_CMD::byteSize) +
+                        mhw_mi_g8_X::MI_BATCH_BUFFER_START_CMD::byteSize +
+                        mhw_mi_g8_X::MI_FLUSH_DW_CMD::byteSize;
 
                     patchListMaxSize +=
-                        PATCH_LIST_COMMAND(MFX_AVC_SLICE_STATE_CMD) +
                         (2 * PATCH_LIST_COMMAND(MFX_AVC_REF_IDX_STATE_CMD)) +
                         (2 * PATCH_LIST_COMMAND(MFX_AVC_WEIGHTOFFSET_STATE_CMD)) +
-                        PATCH_LIST_COMMAND(MFC_AVC_PAK_INSERT_OBJECT_CMD);
+                        PATCH_LIST_COMMAND(MFX_AVC_SLICE_STATE_CMD) +
+                        (2 * PATCH_LIST_COMMAND(MFC_AVC_PAK_INSERT_OBJECT_CMD)) +
+                        PATCH_LIST_COMMAND(MI_BATCH_BUFFER_START_CMD) +
+                        PATCH_LIST_COMMAND(MI_FLUSH_DW_CMD);
                 }
             }
         }
@@ -579,6 +592,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -615,7 +629,7 @@ protected:
 
         cmd.DW1.StandardSelect = CodecHal_GetStandardFromMode(params->Mode);
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -628,6 +642,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->psSurface);
@@ -665,7 +680,7 @@ protected:
                 MOS_ALIGN_CEIL(params->psSurface->VPlaneOffset.iYOffset, MHW_VDBOX_MFX_UV_PLANE_ALIGNMENT_LEGACY);
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -678,6 +693,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -776,7 +792,7 @@ protected:
                 &resourceParams));
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -792,6 +808,7 @@ protected:
 
         MOS_UNUSED(batchBuffer);
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->pAvcPicParams);
@@ -858,7 +875,7 @@ protected:
             cmd.DW16.InterViewOrderDisable = 0;
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -918,7 +935,7 @@ protected:
 
         cmd.DW4.Loadslicepointerflag = 0;
         cmd.DW4.Mbstatenabled = 0; // Disable for the first pass
-        if (params->dwMaxFrameSize > 0 && params->pDeltaQp && params->ucCurrPass)
+        if (params->dwMaxFrameSize > 0 && params->pDeltaQp && params->currPass)
         {
             cmd.DW4.Mbstatenabled = 1;
         }
@@ -933,7 +950,7 @@ protected:
         cmd.DW5.Nonfirstpassflag = 0;
         cmd.DW5.TrellisQuantizationChromaDisableTqchromadisable = true;
 
-        if (params->dwMaxFrameSize && params->ucCurrPass)
+        if (params->dwMaxFrameSize && params->currPass)
         {
             cmd.DW5.Nonfirstpassflag = 1;
         }
@@ -984,7 +1001,7 @@ protected:
             cmd.DW8.Slicedeltaqppmax0 =
                 cmd.DW8.Slicedeltaqpmax1 =
                 cmd.DW8.Slicedeltaqpmax2 =
-                cmd.DW8.Slicedeltaqpmax3 = params->pDeltaQp[params->ucCurrPass];
+                cmd.DW8.Slicedeltaqpmax3 = params->pDeltaQp[params->currPass];
             cmd.DW10.Framebitratemaxunit = 0;
             cmd.DW10.Framebitratemaxunitmode = 0;
             //when FrameBitrateMaxUnit & FrameBitrateMaxUnitMode both are 0, the frame size unit is 128bytes.
@@ -1010,7 +1027,7 @@ protected:
             cmd.DW5.IntraIntermbipcmflagForceipcmcontrolmask = true;
         }
 
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(this->m_osInterface, cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -1021,6 +1038,7 @@ protected:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -1158,7 +1176,7 @@ protected:
             }
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1171,6 +1189,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(avcSliceState);
 
@@ -1200,7 +1219,7 @@ protected:
             nullptr,
             &sliceInfoParam));
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -1213,6 +1232,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(avcSliceState);
         MHW_MI_CHK_NULL(avcSliceState->pAvcSliceParams);
@@ -1276,7 +1296,7 @@ protected:
             nullptr,
             &sliceInfoParam));
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -1319,13 +1339,14 @@ protected:
             cmd.DW1.Headerlengthexcludefrmsize = cmd.DW1.EmulationflagEmulationbytebitsinsertenable ? false
                 : params->bHeaderLengthExcludeFrmSize; // Cannot be set to true if emulation byte bit insertion is enabled
 
-            MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
+            MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(this->m_osInterface, cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
 
             if (params->bLastPicInSeq) // only used by AVC, not used by MPEG2
             {
                 uint32_t lastPicInSeqData = params->dwLastPicInSeqData;
 
                 MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(
+                    this->m_osInterface,
                     cmdBuffer,
                     batchBuffer,
                     &lastPicInSeqData,
@@ -1337,6 +1358,7 @@ protected:
                 uint32_t lastPicInStreamData = params->dwLastPicInStreamData;
 
                 MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(
+                    this->m_osInterface,
                     cmdBuffer,
                     batchBuffer,
                     &lastPicInStreamData,
@@ -1364,11 +1386,11 @@ protected:
             cmd.DW1.DatabyteoffsetSrcdatastartingbyteoffset10 = 0;
             cmd.DW1.Headerlengthexcludefrmsize = cmd.DW1.EmulationflagEmulationbytebitsinsertenable ? false
                 : params->bHeaderLengthExcludeFrmSize; // Cannot be set to true if emulation byte bit insertion is enabled
-            MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
+            MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(this->m_osInterface, cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
 
             // Add actual data
             uint8_t* data = (uint8_t*)(params->pBsBuffer->pBase + params->dwOffset);
-            MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, data, byteSize));
+            MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(this->m_osInterface, cmdBuffer, batchBuffer, data, byteSize));
         }
 
         return eStatus;
@@ -1387,12 +1409,6 @@ protected:
         eStatus = MhwVdboxMfxInterfaceGeneric<TMfxCmds, mhw_mi_g8_X>::AddMfdVp8BsdObjectCmd(cmdBuffer, params);
         MHW_MI_CHK_STATUS(eStatus);
 
-        cmd.DW3.IndirectPartition0DataLength += 1;
-        if (cmd.DW3.IndirectPartition0DataLength == 0)
-        {
-            cmd.DW3.IndirectPartition0DataLength -= 1;
-        }
-
         return eStatus;
     }
 
