@@ -24,13 +24,14 @@
 //! \brief    Defines functions for constructing Vdbox HCP commands on G9 BXT platform
 //!
 
+#include "mos_os_cp_interface_specific.h"
 #include "mhw_vdbox_hcp_g9_bxt.h"
 #include "mhw_mi_hwcmd_g9_X.h"
 #include "mhw_vdbox_vdenc_hwcmd_g9_bxt.h"
 
 void MhwVdboxHcpInterfaceG9Bxt::InitRowstoreUserFeatureSettings()
 {
-    MhwVdboxHcpInterfaceG9::InitRowstoreUserFeatureSettings();
+    MhwVdboxHcpInterfaceG9::InitRowstoreUserFeatureSettings(m_osInterface->pOsContext);
 
     if (m_rowstoreCachingSupported && m_decodeInUse)
     {
@@ -46,7 +47,8 @@ void MhwVdboxHcpInterfaceG9Bxt::InitRowstoreUserFeatureSettings()
             MOS_UserFeature_ReadValue_ID(
                 nullptr,
                 __MEDIA_USER_FEATURE_VALUE_VP9_HVDROWSTORECACHE_DISABLE_ID,
-                &userFeatureData);
+                &userFeatureData,
+                m_osInterface->pOsContext);
 #endif // _DEBUG || _RELEASE_INTERNAL
             m_vp9HvdRowStoreCache.bSupported = userFeatureData.i32Data ? false : true;
 
@@ -55,7 +57,8 @@ void MhwVdboxHcpInterfaceG9Bxt::InitRowstoreUserFeatureSettings()
             MOS_UserFeature_ReadValue_ID(
                 nullptr,
                 __MEDIA_USER_FEATURE_VALUE_VP9_DFROWSTORECACHE_DISABLE_ID,
-                &userFeatureData);
+                &userFeatureData,
+                m_osInterface->pOsContext);
 #endif // _DEBUG || _RELEASE_INTERNAL
             m_vp9DfRowStoreCache.bSupported = userFeatureData.i32Data ? false : true;
         }
@@ -502,7 +505,7 @@ MOS_STATUS MhwVdboxHcpInterfaceG9Bxt::AddHcpVp9PicStateCmd(
         cmd.DW9.AltrefFrameHieghtInPixelsMinus1 = altRefFrameHeight - 1;
     }
 
-    MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
+    MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
 
     return eStatus;
 }
@@ -568,7 +571,7 @@ MOS_STATUS MhwVdboxHcpInterfaceG9Bxt::AddHcpVp9SegmentStateCmd(
         segData = &cmd;
     }
 
-    MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, segData, cmd.byteSize));
+    MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, batchBuffer, segData, cmd.byteSize));
 
     return eStatus;
 }
