@@ -87,6 +87,12 @@ VAStatus DdiDecodeJPEG::ParseSliceParams(
     int32_t startIdx = m_numScans;
     for (j = 0; j < numSlices; j++)
     {
+        if (j + startIdx >= jpegNumComponent ||
+            slcParam[j].num_components > jpegNumComponent)
+        {
+            return VA_STATUS_ERROR_INVALID_PARAMETER;
+        }
+
         for (i = 0; i < slcParam[j].num_components; i++)
         {
             jpegSliceParam->ScanHeader[j + startIdx].ComponentSelector[i] = slcParam[j].components[i].component_selector;
@@ -236,6 +242,7 @@ VAStatus DdiDecodeJPEG::ParseHuffmanTbl(
     VAHuffmanTableBufferJPEGBaseline *huffmanTbl)
 {
     PCODECHAL_DECODE_JPEG_HUFFMAN_TABLE jpegHuffTbl = (PCODECHAL_DECODE_JPEG_HUFFMAN_TABLE)(m_ddiDecodeCtx->DecodeParams.m_huffmanTable);
+    int32_t sumBITS = 0;
 
     if ((jpegHuffTbl == nullptr) ||
         (huffmanTbl == nullptr))
@@ -250,6 +257,18 @@ VAStatus DdiDecodeJPEG::ParseHuffmanTbl(
     {
         if (huffmanTbl->load_huffman_table[i] == BUFFER_LOADED)
         {
+            sumBITS = 0;
+            for (int32_t j = 0; j < JPEG_NUM_HUFF_TABLE_DC_BITS; j++)
+            {
+                sumBITS += huffmanTbl->huffman_table[i].num_dc_codes[j];
+            }
+
+            if (sumBITS > JPEG_NUM_HUFF_TABLE_DC_HUFFVAL)
+            {
+                DDI_ASSERTMESSAGE("Huffman table DC entries number is out of HW limitation.");
+                return VA_STATUS_ERROR_INVALID_PARAMETER;
+            }
+
             //the size of jpegHuffTbl->HuffTable[i].DC_BITS is 12 (defined in driver)
             //the size of huffmanTbl->huffman_table[i].num_dc_codes is 16 (defined in libva)
             //it is using the size of "DC_BITS" for solve the overflow
@@ -491,6 +510,64 @@ VAStatus DdiDecodeJPEG::BeginPicture(
     return vaStatus;
 }
 
+bool DdiDecodeJPEG::CheckFormat(MOS_FORMAT format)
+{
+    bool isSupported = false;
+    CodecDecodeJpegPicParams *jpegPicParam = (CodecDecodeJpegPicParams *)(m_ddiDecodeCtx->DecodeParams.m_picParams);
+    switch (jpegPicParam->m_chromaType)
+    {
+    case jpegYUV400:
+        if (format == Format_400P || format == Format_A8R8G8B8)
+        {
+            isSupported = true;
+        }
+        break;
+    case jpegYUV420:
+        if (format == Format_NV12 || format == Format_YUY2 || format == Format_UYVY || format == Format_IMC3 || format == Format_A8R8G8B8)
+        {
+            isSupported = true;
+        }
+        break;
+    case jpegYUV411:
+        if (format == Format_411P)
+        {
+            isSupported = true;
+        }
+        break;
+    case jpegYUV422H2Y:
+    case jpegYUV422H4Y:
+        if (format == Format_NV12 || format == Format_YUY2 || format == Format_UYVY || format == Format_422H || format == Format_A8R8G8B8)
+        {
+            isSupported = true;
+        }
+        break;
+    case jpegYUV422V2Y:
+    case jpegYUV422V4Y:
+        if (format == Format_NV12 || format == Format_422V || format == Format_A8R8G8B8)
+        {
+            isSupported = true;
+        }
+        break;
+    case jpegYUV444:
+        if (format == Format_444P || format == Format_A8R8G8B8)
+        {
+            isSupported = true;
+        }
+        break;
+    case jpegRGB:
+    case jpegBGR:
+        if (format == Format_RGBP || format == Format_BGRP ||format == Format_A8R8G8B8)
+        {
+            isSupported = true;
+        }
+        break;
+    default:
+        break;
+    }
+
+    return isSupported;
+}
+
 VAStatus DdiDecodeJPEG::InitDecodeParams(
     VADriverContextP ctx,
     VAContextID      context)
@@ -607,13 +684,21 @@ VAStatus DdiDecodeJPEG::SetDecodeParams()
     if((m_ddiDecodeCtx->RTtbl.pCurrentRT->format == Media_Format_NV12)
         &&(jpegPicParam->m_chromaType == jpegYUV444))
     {
+        UnRegisterRTSurfaces(&(m_ddiDecodeCtx->RTtbl), m_ddiDecodeCtx->RTtbl.pCurrentRT);
         m_ddiDecodeCtx->RTtbl.pCurrentRT = DdiMedia_ReplaceSurfaceWithNewFormat(m_ddiDecodeCtx->RTtbl.pCurrentRT, Media_Format_444P);
+        RegisterRTSurfaces(&(m_ddiDecodeCtx->RTtbl), m_ddiDecodeCtx->RTtbl.pCurrentRT);
     }
     if(m_ddiDecodeCtx->RTtbl.pCurrentRT != nullptr)
     {
         DdiMedia_MediaSurfaceToMosResource((&(m_ddiDecodeCtx->RTtbl))->pCurrentRT, &(m_destSurface.OsResource));
     }
 
+    if (!CheckFormat(m_destSurface.OsResource.Format))
+    {
+        DDI_ASSERTMESSAGE("Surface fomrat of decoded surface is inconsistent with Codec bitstream!\n");
+        return VA_STATUS_ERROR_INVALID_PARAMETER;
+    }
+
     (&m_ddiDecodeCtx->DecodeParams)->m_destSurface = &m_destSurface;
 
     (&m_ddiDecodeCtx->DecodeParams)->m_deblockSurface = nullptr;
