@@ -28,6 +28,9 @@
 #define __MEDIA_LIBVA_CAPS_H__
 
 #include "va/va.h"
+#include "codec_def_common.h"
+#include "codec_def_common_encode.h"
+#include "codec_def_encode_jpeg.h"
 
 #include <vector>
 #include <map>
@@ -844,9 +847,13 @@ protected:
 #endif
     static const uint16_t m_maxProfiles = 17; //!< Maximum number of supported profiles
     static const uint16_t m_maxProfileEntries = 64; //!< Maximum number of supported profile & entrypoint combinations
-    static const uint32_t m_numVpSurfaceAttr = 20; //!< Number of VP surface attributes
-    static const uint32_t m_numJpegSurfaceAttr = 7; //!< Number of JPEG surface attributes
-    static const uint32_t m_numJpegEncSurfaceAttr = 4; //!< Number of JPEG encode surface attributes
+#if VA_CHECK_VERSION(1, 9, 0)
+    static const uint32_t m_numVpSurfaceAttr = 24; //!< Number of VP surface attributes
+#else
+    static const uint32_t m_numVpSurfaceAttr = 22; //!< Number of VP surface attributes
+#endif
+    static const uint32_t m_numJpegSurfaceAttr = 8; //!< Number of JPEG surface attributes
+    static const uint32_t m_numJpegEncSurfaceAttr = 5; //!< Number of JPEG encode surface attributes
     static const uint16_t m_maxEntrypoints = 7; //!<  Maximum number of supported entrypoints
     static const uint32_t m_decSliceMode[2]; //!< Store 2 decode slices modes
     static const uint32_t m_decProcessMode[2]; //!< Store 2 decode process modes
