@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -43,6 +43,7 @@
 #include "decode_cp_bitstream_m12.h"
 #include "decode_marker_packet_g12.h"
 #include "decode_predication_packet_g12.h"
+#include "mos_interface.h"
 
 namespace decode
 {
@@ -105,10 +106,6 @@ MOS_STATUS Vp9PipelineG12::Prepare(void *params)
                 DECODE_CHK_STATUS(DumpParams(*m_basicFeature));
                 );
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-            TraceDataDumpInternalBuffers(*m_basicFeature);
-#endif
-
             DecodeStatusParameters inputParameters = {};
             MOS_ZeroMemory(&inputParameters, sizeof(DecodeStatusParameters));
             inputParameters.statusReportFeedbackNumber = m_basicFeature->m_vp9PicParams->StatusReportFeedbackNumber;
@@ -118,6 +115,14 @@ MOS_STATUS Vp9PipelineG12::Prepare(void *params)
             inputParameters.currOriginalPic            = m_basicFeature->m_curRenderPic;
             inputParameters.currDecodedPicRes          = m_basicFeature->m_destSurface.OsResource;
             inputParameters.numUsedVdbox               = m_numVdbox;
+            
+            CODECHAL_DEBUG_TOOL(
+                if (m_streamout != nullptr)  
+                {  
+                    DECODE_CHK_STATUS(m_streamout->InitStatusReportParam(inputParameters));  
+                }  
+            );
+
 #if (_DEBUG || _RELEASE_INTERNAL)
 #ifdef _DECODE_PROCESSING_SUPPORTED
             DecodeDownSamplingFeature *downSamplingFeature = dynamic_cast<DecodeDownSamplingFeature *>(
@@ -125,7 +130,7 @@ MOS_STATUS Vp9PipelineG12::Prepare(void *params)
             if (downSamplingFeature != nullptr)
             {
                 auto frameIdx                   = m_basicFeature->m_curRenderPic.FrameIdx;
-                inputParameters.sfcOutputPicRes = &downSamplingFeature->m_outputSurfaceList[frameIdx].OsResource;
+                inputParameters.sfcOutputSurface = &downSamplingFeature->m_outputSurfaceList[frameIdx];
                 if (downSamplingFeature->m_histogramBuffer != nullptr)
                 {
                     inputParameters.histogramOutputBuf = &downSamplingFeature->m_histogramBuffer->OsResource;
@@ -153,7 +158,9 @@ MOS_STATUS Vp9PipelineG12::InitContexOption(Vp9BasicFeature &basicFeature)
     scalPars.frameWidth         = basicFeature.m_frameWidthAlignedMinBlk;
     scalPars.frameHeight        = basicFeature.m_frameHeightAlignedMinBlk;
     scalPars.numVdbox           = m_numVdbox;
-    if (m_osInterface->pfnIsMultipleCodecDevicesInUse(m_osInterface))
+    bool isMultiDevices = false, isMultiEngine = false;
+    m_osInterface->pfnGetMultiEngineStatus(m_osInterface, nullptr, COMPONENT_Encode, isMultiDevices, isMultiEngine);
+    if (isMultiDevices && !isMultiEngine)
     {
         scalPars.disableScalability = true;
     }
@@ -200,6 +207,9 @@ MOS_STATUS Vp9PipelineG12::InitContexOption(Vp9BasicFeature &basicFeature)
         scalPars.disableVirtualTile = true;
     }
 
+    if (!scalPars.disableScalability)
+        m_osInterface->pfnSetMultiEngineEnabled(m_osInterface, COMPONENT_Decode, true);
+
     DECODE_CHK_STATUS(m_scalabOption.SetScalabilityOption(&scalPars));
     return MOS_STATUS_SUCCESS;
 }
@@ -230,7 +240,9 @@ MOS_STATUS Vp9PipelineG12::Execute()
             {
                 DECODE_CHK_STATUS(UserFeatureReport());
             }
-            m_basicFeature->m_frameNum++;
+
+            DecodeFrameIndex++;
+            m_basicFeature->m_frameNum = DecodeFrameIndex;
 
             DECODE_CHK_STATUS(m_statusReport->Reset());
 
@@ -276,6 +288,8 @@ MOS_STATUS Vp9PipelineG12::Destroy()
 
     Uninitialize();
 
+    m_osInterface->pfnSetMultiEngineEnabled(m_osInterface, COMPONENT_Decode, false);
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -294,7 +308,6 @@ MOS_STATUS Vp9PipelineG12::Initialize(void *settings)
     DECODE_CHK_STATUS(MediaPipeline::InitPlatform());
     DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopyWrapper());
     DECODE_CHK_NULL(m_mediaCopyWrapper);
-    m_mediaCopyWrapper->CreateMediaCopyState();
 
     DECODE_CHK_NULL(m_waTable);
 
@@ -307,10 +320,12 @@ MOS_STATUS Vp9PipelineG12::Initialize(void *settings)
         m_mediaCopyWrapper->SetMediaCopyState(m_hwInterface->CreateMediaCopy(m_osInterface));
     }
 
-#if USE_CODECHAL_DEBUG_TOOL
-    DECODE_CHK_NULL(m_debugInterface);
-    DECODE_CHK_STATUS(m_debugInterface->SetFastDumpConfig(m_mediaCopyWrapper->GetMediaCopyState()));
-#endif
+    CODECHAL_DEBUG_TOOL(
+        m_debugInterface = MOS_New(CodechalDebugInterface);
+        DECODE_CHK_NULL(m_debugInterface);
+        DECODE_CHK_STATUS(
+            m_debugInterface->Initialize(m_hwInterface, codecSettings->codecFunction, m_mediaCopyWrapper)););
+
     if (m_hwInterface->m_hwInterfaceNext)
     {
         m_hwInterface->m_hwInterfaceNext->legacyHwInterface = m_hwInterface;
@@ -332,7 +347,7 @@ MOS_STATUS Vp9PipelineG12::Initialize(void *settings)
     m_decodecp = Create_DecodeCpInterface(codecSettings, m_hwInterface->GetCpInterface(), m_hwInterface->GetOsInterface());
     if (m_decodecp)
     {
-        m_decodecp->RegisterParams(codecSettings);
+        DECODE_CHK_STATUS(m_decodecp->RegisterParams(codecSettings));
     }
     DECODE_CHK_STATUS(CreateFeatureManager());
     DECODE_CHK_STATUS(m_featureManager->Init(codecSettings));
@@ -353,9 +368,8 @@ MOS_STATUS Vp9PipelineG12::Initialize(void *settings)
     DECODE_CHK_NULL(bufferUpdatePipeline);
     DECODE_CHK_STATUS(m_preSubPipeline->Register(*bufferUpdatePipeline));
     DECODE_CHK_STATUS(bufferUpdatePipeline->Init(*codecSettings));
-#ifdef _MMC_SUPPORTED
+
     DECODE_CHK_STATUS(InitMmcState());
-#endif
 
     return MOS_STATUS_SUCCESS;
 }
@@ -449,12 +463,11 @@ MOS_STATUS Vp9PipelineG12::CreatePreSubPipeLines(DecodeSubPipelineManager &subPi
 
 MOS_STATUS Vp9PipelineG12::InitMmcState()
 {
-#ifdef _MMC_SUPPORTED
     DECODE_CHK_NULL(m_hwInterface);
     m_mmcState = MOS_New(Vp9DecodeMemCompM12, m_hwInterface);
     DECODE_CHK_NULL(m_mmcState);
     DECODE_CHK_STATUS(m_basicFeature->SetMmcState(m_mmcState->IsMmcEnabled()));
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -467,13 +480,12 @@ MOS_STATUS Vp9PipelineG12::DumpParams(Vp9BasicFeature &basicFeature)
     m_debugInterface->m_secondField               = basicFeature.m_secondField;
     m_debugInterface->m_bufferDumpFrameNum        = basicFeature.m_frameNum;
 
-    DECODE_CHK_STATUS(DumpPicParams(
-        basicFeature.m_vp9PicParams));
+    DECODE_CHK_STATUS(DumpPicParams(basicFeature.m_vp9PicParams));
+    DECODE_CHK_STATUS(DumpSliceParams(basicFeature.m_vp9SliceParams));
+    DECODE_CHK_STATUS(DumpSegmentParams(basicFeature.m_vp9SegmentParams));
+    DECODE_CHK_STATUS(DumpBitstream(&basicFeature.m_resDataBuffer.OsResource, basicFeature.m_dataSize, 0));
 
-    DECODE_CHK_STATUS(DumpSegmentParams(
-        basicFeature.m_vp9SegmentParams));
-
-     DECODE_CHK_STATUS(m_debugInterface->DumpBuffer(
+    DECODE_CHK_STATUS(m_debugInterface->DumpBuffer(
         &(basicFeature.m_resVp9SegmentIdBuffer->OsResource),
         CodechalDbgAttr::attrSegId,
         "SegId_beforeHCP",
@@ -485,53 +497,6 @@ MOS_STATUS Vp9PipelineG12::DumpParams(Vp9BasicFeature &basicFeature)
         "PakHwCoeffProbs_beforeHCP",
         CODEC_VP9_PROB_MAX_NUM_ELEM));
 
-    //dump bitstream
-    DECODE_CHK_STATUS(m_debugInterface->DumpBuffer(
-        &basicFeature.m_resDataBuffer.OsResource, 
-        CodechalDbgAttr::attrBitstream, 
-        "_DEC", 
-        basicFeature.m_dataSize, 0, CODECHAL_NUM_MEDIA_STATES));
-
-    return MOS_STATUS_SUCCESS;
-}
-#endif
-
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-MOS_STATUS Vp9PipelineG12::TraceDataDumpInternalBuffers(Vp9BasicFeature &basicFeature)
-{  
-    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_INTERNAL))
-    {
-        if (!m_allocator->ResourceIsNull(&(basicFeature.m_resVp9SegmentIdBuffer->OsResource)))
-        {
-            ResourceAutoLock resLock(m_allocator, &(basicFeature.m_resVp9SegmentIdBuffer->OsResource));
-            auto             pData = (uint8_t *)resLock.LockResourceForRead();
-            DECODE_CHK_NULL(pData);
-
-            MOS_TraceDataDump(
-                "Decode_Vp9SegmentIdBeforeHCP",
-                0,
-                pData,
-                basicFeature.m_allocatedWidthInSb * basicFeature.m_allocatedHeightInSb * CODECHAL_CACHELINE_SIZE);
-
-            m_allocator->UnLock(&(basicFeature.m_resVp9SegmentIdBuffer->OsResource));
-        }
-
-        if (!m_allocator->ResourceIsNull(&(basicFeature.m_resVp9ProbBuffer[basicFeature.m_frameCtxIdx]->OsResource)))
-        {
-            ResourceAutoLock resLock(m_allocator, &(basicFeature.m_resVp9ProbBuffer[basicFeature.m_frameCtxIdx]->OsResource));
-            auto             pData = (uint8_t *)resLock.LockResourceForRead();
-            DECODE_CHK_NULL(pData);
-
-            MOS_TraceDataDump(
-                "Decode_Vp9CoeffProbsBeforeHCP",
-                0,
-                pData,
-                CODEC_VP9_PROB_MAX_NUM_ELEM);
-
-            m_allocator->UnLock(&(basicFeature.m_resVp9ProbBuffer[basicFeature.m_frameCtxIdx]->OsResource));
-        }
-    }
-
     return MOS_STATUS_SUCCESS;
 }
 #endif
