@@ -62,43 +62,21 @@ namespace encode
 
         virtual ~Av1VdencPktXe_M_Base() {}
 
-        //!
-        //! \brief  Add the command sequence into the commandBuffer and
-        //!         and return to the caller task
-        //! \param  [in] commandBuffer
-        //!         Pointer to the command buffer which is allocated by caller
-        //! \return MOS_STATUS
-        //!         MOS_STATUS_SUCCESS if success, else fail reason
-        //!
-        virtual MOS_STATUS Submit(
-            MOS_COMMAND_BUFFER* commandBuffer,
-            uint8_t packetPhase = otherPacket) override;
-
     protected:
-        MOS_STATUS PatchTileLevelCommands(MOS_COMMAND_BUFFER &cmdBuffer, uint8_t packetPhase);
         MOS_STATUS AddOneTileCommands(
             MOS_COMMAND_BUFFER  &cmdBuffer,
             uint32_t            tileRow,
             uint32_t            tileCol,
-            uint32_t            tileRowPass = 0);
+            uint32_t            tileRowPass = 0) override;
 
-        MOS_STATUS EnsureAllCommandsExecuted(MOS_COMMAND_BUFFER &cmdBuffer);
-        MOS_STATUS PatchPictureLevelCommands(const uint8_t &packetPhase, MOS_COMMAND_BUFFER  &cmdBuffer);
+        MOS_STATUS EnsureAllCommandsExecuted(MOS_COMMAND_BUFFER &cmdBuffer) override;
 
         virtual MOS_STATUS AllocateResources() override;
 
         virtual MOS_STATUS CalculateAvpPictureStateCommandSize(uint32_t * commandsSize, uint32_t * patchListSize) override;
         virtual MOS_STATUS CalculateAvpCommandsSize() override;
 
-        MOS_STATUS RegisterPostCdef();
-
-        MOS_STATUS AddAllCmds_AVP_SEGMENT_STATE(PMOS_COMMAND_BUFFER cmdBuffer) const;
-
-        MOS_STATUS AddAllCmds_AVP_PIPE_MODE_SELECT(PMOS_COMMAND_BUFFER cmdBuffer) const;
-
-#if USE_CODECHAL_DEBUG_TOOL
-        MOS_STATUS DumpStatistics();
-#endif  // USE_CODECHAL_DEBUG_TOOL
+        MOS_STATUS RegisterPostCdef() override;
 
     private:
         uint16_t m_tileColStartSb[64];  //!< tile column start SB
