@@ -26,6 +26,12 @@
 //!
 
 #include "media_copy_xe_xpm_base.h"
+#include "media_vebox_copy.h"
+#include "media_blt_copy_xe_xpm_base.h"
+#include "media_interfaces_mhw.h"
+#include "mos_os.h"
+#include "mos_resource_defs.h"
+#include "mos_utilities.h"
 
 MediaCopyStateXe_Xpm_Base::MediaCopyStateXe_Xpm_Base() :
     MediaCopyBaseState()
@@ -43,13 +49,15 @@ MOS_STATUS MediaCopyStateXe_Xpm_Base::Initialize(  PMOS_INTERFACE  osInterface,
     m_osInterface   = osInterface;
     m_mhwInterfaces = mhwInterfaces;
 
-    MCPY_CHK_STATUS_RETURN(MediaCopyBaseState::Initialize(osInterface, mhwInterfaces));
+    MCPY_CHK_STATUS_RETURN(MediaCopyBaseState::Initialize(osInterface));
 
     // blt init
-    m_bltState = MOS_New(BltStateXe_Xpm, m_osInterface, m_mhwInterfaces);
-    MCPY_CHK_NULL_RETURN(m_bltState);
-    MCPY_CHK_STATUS_RETURN(m_bltState->Initialize());
-
+    if (nullptr == m_bltState)
+    {
+        m_bltState = MOS_New(BltStateXe_Xpm, m_osInterface, m_mhwInterfaces);
+        MCPY_CHK_NULL_RETURN(m_bltState);
+        MCPY_CHK_STATUS_RETURN(m_bltState->Initialize());
+    }
     // vebox init
     if (nullptr == m_veboxCopyState)
     {
@@ -60,27 +68,14 @@ MOS_STATUS MediaCopyStateXe_Xpm_Base::Initialize(  PMOS_INTERFACE  osInterface,
     return eStatus;
 }
 
-//!
-//! \brief    surface copy pre process.
-//! \details  pre process before doing surface copy.
-//! \param    preferMethod
-//!           [in] Preferred media copy method
-//! \return   MOS_STATUS
-//!           Return MOS_STATUS_SUCCESS if support, otherwise return unspoort.
-//!
-MOS_STATUS MediaCopyStateXe_Xpm_Base::PreProcess(MCPY_METHOD preferMethod)
+MOS_STATUS MediaCopyStateXe_Xpm_Base::PreCheckCpCopy(
+    MCPY_STATE_PARAMS src, MCPY_STATE_PARAMS dest, MCPY_METHOD preferMethod)
 {
-    if ((preferMethod == MCPY_METHOD_POWERSAVING)
-        && m_mcpyEngineCaps.engineBlt
-        && (m_mcpySrc.CpMode == MCPY_CPMODE_CP)
-        && (m_mcpyDst.CpMode == MCPY_CPMODE_CLEAR))
+    if (preferMethod == MCPY_METHOD_POWERSAVING && 
+        (src.CpMode == MCPY_CPMODE_CP || dest.CpMode == MCPY_CPMODE_CP))
     {
-        //Allow blt engine to do copy when dst buffer is staging buffer and allocate in system mem, since protection off with blt engine.
-        m_allowCPBltCopy = true;
-    }
-    else
-    {
-        m_allowCPBltCopy = false;
+        MCPY_ASSERTMESSAGE("BLT Copy with CP is not supported");
+        return MOS_STATUS_PLATFORM_NOT_SUPPORTED;
     }
 
     return MOS_STATUS_SUCCESS;
@@ -90,6 +85,26 @@ MediaCopyStateXe_Xpm_Base::~MediaCopyStateXe_Xpm_Base()
 {
     MOS_Delete(m_bltState);
     MOS_Delete(m_veboxCopyState);
+    if (m_mhwInterfaces)
+    {
+        if (m_mhwInterfaces->m_cpInterface)
+        {
+            if (m_osInterface)
+            {
+                m_osInterface->pfnDeleteMhwCpInterface(m_mhwInterfaces->m_cpInterface);
+                m_mhwInterfaces->m_cpInterface = nullptr;
+            }
+            else
+            {
+                MHW_ASSERTMESSAGE("Failed to destroy cpInterface.");
+            }
+        }
+        MOS_Delete(m_mhwInterfaces->m_miInterface);
+        MOS_Delete(m_mhwInterfaces->m_veboxInterface);
+        MOS_Delete(m_mhwInterfaces->m_bltInterface);
+        MOS_Delete(m_mhwInterfaces);
+        m_mhwInterfaces = nullptr;
+    }
 }
 
 bool MediaCopyStateXe_Xpm_Base::RenderFormatSupportCheck(PMOS_RESOURCE src, PMOS_RESOURCE dst)
@@ -137,7 +152,7 @@ bool MediaCopyStateXe_Xpm_Base::IsVeboxCopySupported(PMOS_RESOURCE src, PMOS_RES
 
     if (m_veboxCopyState)
     {
-        supported = m_veboxCopyState->IsFormatSupported(src) && m_veboxCopyState->IsFormatSupported(dst);
+        supported = m_veboxCopyState->IsSurfaceSupported(src) && m_veboxCopyState->IsSurfaceSupported(dst);
     }
 
     if (src->TileType == MOS_TILE_LINEAR &&
