@@ -71,7 +71,8 @@ extern const RENDERHAL_STATE_HEAP_SETTINGS g_cRenderHal_State_Heap_Settings_g12
     RENDERHAL_SSH_BINDING_TABLES,              //!< iBindingTables
     RENDERHAL_SSH_SURFACE_STATES,              //!< iSurfaceStates
     RENDERHAL_SSH_SURFACES_PER_BT,             //!< iSurfacesPerBT
-    RENDERHAL_SSH_BINDING_TABLE_ALIGN          //!< iBTAlignment
+    RENDERHAL_SSH_BINDING_TABLE_ALIGN,         //!< iBTAlignment
+    MOS_CODEC_RESOURCE_USAGE_BEGIN_CODEC       //!< heapUsageType
 };
 
 const uint32_t g_cLookup_RotationMode_g12[8] = 
@@ -217,6 +218,15 @@ MOS_STATUS XRenderHal_Interface_G12_Base::SetupSurfaceState (
                                                             .DwordValue;
                 MHW_RENDERHAL_NORMALMESSAGE(" MOS_RESOURCE_USAGE_CCS_MEDIA_WRITABLE is queried, and target SurfStateParams.dwCacheabilityControl = %d \n", SurfStateParams.dwCacheabilityControl);
             }
+            #if (_DEBUG || _RELEASE_INTERNAL)
+                pSurface->OsResource.memObjCtrlState.DwordValue = SurfStateParams.dwCacheabilityControl;
+                pParams->MemObjCtl                              = SurfStateParams.dwCacheabilityControl;
+                pSurface->oldCacheSetting                       = (SurfStateParams.dwCacheabilityControl >> 1) & 0x0000003f;
+                if (pParams->isOutput)
+                {
+                    pRenderHal->oldCacheSettingForTargetSurface = pSurface->oldCacheSetting;
+                }
+            #endif
         }
     #endif
         if (IsFormatMMCSupported(pSurface->Format) &&
