@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -48,6 +48,9 @@ namespace decode
         DECODE_CHK_STATUS(
             CodecHalAllocateDataList((CODEC_REF_LIST_AV1 **)m_refList, CODECHAL_MAX_DPB_NUM_LST_AV1));
 
+        DECODE_CHK_NULL(m_basicFeature);
+        m_osInterface = m_basicFeature->GetOsInterface();
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -100,12 +103,18 @@ namespace decode
             else
             {
                 PCODEC_PICTURE refFrameList = &(picParams.m_refFrameMap[0]);
-                uint8_t refPicIndex = picParams.m_refFrameIdx[i];
-                if (refPicIndex >= av1TotalRefsPerFrame)
+                uint8_t        refPicIndex  = picParams.m_refFrameIdx[i];
+                uint8_t        frameIdx     = 0xFF;
+                if (refPicIndex < av1TotalRefsPerFrame &&
+                    refFrameList[refPicIndex].FrameIdx < CODECHAL_MAX_DPB_NUM_AV1)
                 {
-                    continue;
+                    frameIdx = refFrameList[refPicIndex].FrameIdx;
                 }
-                m_activeReferenceList.push_back(refFrameList[refPicIndex].FrameIdx);
+                else
+                {
+                    MOS_STATUS hr = GetValidReferenceIndex(&frameIdx);
+                }
+                m_activeReferenceList.push_back(frameIdx);
             }
         }
 
@@ -116,7 +125,7 @@ namespace decode
     {
         DECODE_FUNC_CALL();
 
-        if (frameIndex > CODECHAL_MAX_DPB_NUM_AV1)
+        if (frameIndex >= CODECHAL_MAX_DPB_NUM_AV1)
         {
             DECODE_ASSERTMESSAGE("Invalid reference frame index");
             return nullptr;
@@ -177,6 +186,10 @@ namespace decode
         for (auto i = 0; i < av1NumInterRefFrames; i++)
         {
             auto    index    = m_picParams->m_refFrameIdx[i];
+            if (index >= av1TotalRefsPerFrame)
+            {
+                continue;
+            }
             uint8_t frameIdx = m_picParams->m_refFrameMap[index].FrameIdx;
             if (frameIdx >= m_basicFeature->m_maxFrameIndex)
             {
@@ -274,6 +287,24 @@ namespace decode
         m_currRefList->m_segmentEnable  = picParams.m_av1SegData.m_enabled;
         m_currRefList->m_frameType      = picParams.m_picInfoFlags.m_fields.m_frameType;
 
+        if (m_osInterface->pfnIsMismatchOrderProgrammingSupported() && !picParams.m_seqInfoFlags.m_fields.m_filmGrainParamsPresent)
+        {
+            uint8_t surfIndex = 0;
+            while (surfIndex <= CODECHAL_MAX_DPB_NUM_AV1)
+            {
+                if (!m_allocator->ResourceIsNull(&m_basicFeature->m_refFrameSurface[surfIndex].OsResource))
+                {
+                    auto refList            = m_refList[surfIndex];
+                    refList->resRefPic      = m_basicFeature->m_refFrameSurface[surfIndex].OsResource;
+                    refList->m_frameWidth   = picParams.m_superResUpscaledWidthMinus1 + 1;  //DPB buffer are always stored in full frame resolution (Super-Res up-scaled resolution)
+                    refList->m_frameHeight  = picParams.m_superResUpscaledHeightMinus1 + 1;
+                    m_currRefList->m_miCols = MOS_ALIGN_CEIL(picParams.m_frameWidthMinus1 + 1, 8) >> av1MiSizeLog2;
+                    m_currRefList->m_miRows = MOS_ALIGN_CEIL(picParams.m_frameHeightMinus1 + 1, 8) >> av1MiSizeLog2;
+                }
+                surfIndex++;
+            }
+        }
+
         if (!AV1_KEY_OR_INRA_FRAME(picParams.m_picInfoFlags.m_fields.m_frameType) &&
             picParams.m_seqInfoFlags.m_fields.m_enableOrderHint)
         {
@@ -520,6 +551,12 @@ namespace decode
         uint8_t validfPicIndex    = 0;
         bool    hasValidRefIndex = false;
 
+        //To support mismatch order programming, disable frame error concelment as refenrence list is unreliable here.
+        if (m_osInterface->pfnIsMismatchOrderProgrammingSupported())
+        {
+            return hr;
+        }
+
         for (auto i = 0; i < av1NumInterRefFrames; i++)
         {
             uint8_t refPicIndex = picParams.m_refFrameIdx[i];
