@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022, Intel Corporation
+* Copyright (c) 2022-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -113,10 +113,8 @@ namespace decode
         m_hevcRextPicParams  = m_hevcBasicFeature->m_hevcRextPicParams;
         m_hevcSccPicParams   = m_hevcBasicFeature->m_hevcSccPicParams;
 
-#ifdef _MMC_SUPPORTED
         m_mmcState = m_hevcPipeline->GetMmcState();
         DECODE_CHK_NULL(m_mmcState);
-#endif
 
         DECODE_CHK_STATUS(SetRowstoreCachingOffsets());
         DECODE_CHK_STATUS(AllocateVariableResources());
@@ -472,7 +470,6 @@ namespace decode
             params.defaultAlphaValue = 0xffff;
         }
 
-#ifdef _MMC_SUPPORTED
         if (m_curHcpSurfStateId == CODECHAL_HCP_DECODED_SURFACE_ID)
         {
             DECODE_CHK_STATUS(m_mmcState->SetSurfaceMmcState(psSurface));
@@ -508,7 +505,7 @@ namespace decode
                     DECODE_CHK_STATUS(m_mmcState->GetResourceMmcState(pipeBufAddrPar.presReferences[i], mmcState));
                     params.refsMmcEnable |= (mmcState == MOS_MEMCOMP_RC || mmcState == MOS_MEMCOMP_MC) ? (1 << i) : 0;
                     params.refsMmcType |= (mmcState == MOS_MEMCOMP_RC) ? (1 << i) : 0;
-                    if (mmcState == MOS_MEMCOMP_RC || mmcState == MOS_MEMCOMP_MC)
+                    if (m_mmcState->IsMmcEnabled())
                     {
                         DECODE_CHK_STATUS(m_mmcState->GetResourceMmcFormat(pipeBufAddrPar.presReferences[i], params.dwCompressionFormat));
                     }
@@ -528,14 +525,13 @@ namespace decode
                     DECODE_CHK_STATUS(m_mmcState->GetResourceMmcState(pipeBufAddrPar.presReferences[i], mmcState));
                     params.refsMmcEnable |= (mmcState == MOS_MEMCOMP_RC || mmcState == MOS_MEMCOMP_MC) ? (1 << i) : 0;
                     params.refsMmcType |= (mmcState == MOS_MEMCOMP_RC) ? (1 << i) : 0;
-                    if (mmcState == MOS_MEMCOMP_RC || mmcState == MOS_MEMCOMP_MC)
+                    if (m_mmcState->IsMmcEnabled())
                     {
                         DECODE_CHK_STATUS(m_mmcState->GetResourceMmcFormat(pipeBufAddrPar.presReferences[i], params.dwCompressionFormat));
                     }
                 }
             }
         }
-#endif
 
         return MOS_STATUS_SUCCESS;
     }
@@ -603,6 +599,48 @@ namespace decode
         return MOS_STATUS_SUCCESS;
     }
 
+#if USE_CODECHAL_DEBUG_TOOL
+    MOS_STATUS HevcDecodePicPkt::DumpResources(
+        HCP_PIPE_BUF_ADDR_STATE_PAR &pipeBufAddrParams,
+        uint8_t                      activeRefListSize,
+        uint32_t                     mvBufferSize) const
+    {
+        DECODE_FUNC_CALL();
+
+        CodechalDebugInterface *debugInterface = m_pipeline->GetDebugInterface();
+        DECODE_CHK_NULL(debugInterface);
+
+        for (uint32_t i = 0; i < activeRefListSize; i++)
+        {
+            if (pipeBufAddrParams.presReferences[i] != nullptr)
+            {
+                MOS_SURFACE refSurface;
+                MOS_ZeroMemory(&refSurface, sizeof(MOS_SURFACE));
+                refSurface.OsResource = *(pipeBufAddrParams.presReferences[i]);
+                DECODE_CHK_STATUS(CodecUtilities::CodecHalGetResourceInfo(m_osInterface, &refSurface));
+
+                std::string refSurfDumpName = "RefSurf[" + std::to_string(i) + "]";
+                DECODE_CHK_STATUS(debugInterface->DumpYUVSurface(
+                    &refSurface,
+                    CodechalDbgAttr::attrDecodeReferenceSurfaces,
+                    refSurfDumpName.c_str()));
+            }
+
+            if (pipeBufAddrParams.presColMvTempBuffer[i] != nullptr)
+            {
+                std::string mvBufDumpName = "_DEC_" + std::to_string(i);
+                DECODE_CHK_STATUS(debugInterface->DumpBuffer(
+                    pipeBufAddrParams.presColMvTempBuffer[i],
+                    CodechalDbgAttr::attrMvData,
+                    mvBufDumpName.c_str(),
+                    mvBufferSize));
+            }
+        }
+
+        return MOS_STATUS_SUCCESS;
+    }
+#endif
+
     MHW_SETPAR_DECL_SRC(HCP_PIPE_BUF_ADDR_STATE, HevcDecodePicPkt)
     {
         DECODE_FUNC_CALL();
@@ -612,9 +650,7 @@ namespace decode
         PMOS_SURFACE destSurface   = &(m_hevcBasicFeature->m_destSurface);
         params.psPreDeblockSurface = destSurface;
 
-#ifdef _MMC_SUPPORTED
         DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcState(destSurface, &params.PreDeblockSurfMmcState));
-#endif
 
         params.presMfdDeblockingFilterRowStoreScratchBuffer    = &(m_resMfdDeblockingFilterRowStoreScratchBuffer->OsResource);
         params.presDeblockingFilterTileRowStoreScratchBuffer   = &(m_resDeblockingFilterTileRowStoreScratchBuffer->OsResource);
@@ -685,34 +721,7 @@ namespace decode
             params.IBCRefIdxMask = refIdxMask;
         }
 
-        CODECHAL_DEBUG_TOOL(
-            CodechalDebugInterface *debugInterface = m_pipeline->GetDebugInterface();
-            DECODE_CHK_NULL(debugInterface);
-            for (uint32_t n = 0; n < CODECHAL_MAX_CUR_NUM_REF_FRAME_HEVC; n++) {
-                if (params.presReferences[n] != nullptr)
-                {
-                    MOS_SURFACE dstSurface;
-                    MOS_ZeroMemory(&dstSurface, sizeof(MOS_SURFACE));
-                    dstSurface.OsResource = *(params.presReferences[n]);
-                    DECODE_CHK_STATUS(CodecUtilities::CodecHalGetResourceInfo(m_osInterface, &dstSurface));
-
-                    std::string refSurfDumpName = "RefSurf_" + std::to_string(n);
-                    DECODE_CHK_STATUS(debugInterface->DumpYUVSurface(
-                        &dstSurface,
-                        CodechalDbgAttr::attrDecodeReferenceSurfaces,
-                        refSurfDumpName.c_str()));
-                }
-
-                if (params.presColMvTempBuffer[n] != nullptr)
-                {
-                    std::string mvBufDumpName = "_DEC_" + std::to_string(n);
-                    DECODE_CHK_STATUS(debugInterface->DumpBuffer(
-                        params.presColMvTempBuffer[n],
-                        CodechalDbgAttr::attrMvData,
-                        mvBufDumpName.c_str(),
-                        curMvBuffer->size));
-                }
-            })
+        CODECHAL_DEBUG_TOOL(DECODE_CHK_STATUS(DumpResources(params, activeRefList.size(), curMvBuffer->size)));        
 
         return MOS_STATUS_SUCCESS;
     }
@@ -809,7 +818,7 @@ namespace decode
                         }
                     }
 
-                    m_hcpItf->MHW_ADDCMD_F(HCP_QM_STATE)(&cmdBuffer);
+                    DECODE_CHK_STATUS(m_hcpItf->MHW_ADDCMD_F(HCP_QM_STATE)(&cmdBuffer));
                 }
             }
         }
@@ -916,6 +925,5 @@ namespace decode
         
         return MOS_STATUS_SUCCESS;
     }
-
 }
 
