@@ -228,6 +228,12 @@ MOS_STATUS AvcReferenceFrames::UpdateSlice()
             picParams->pic_init_qp_minus26 + 26 + slcParams->slice_qp_delta;
     }
 
+    if (slcParams->num_ref_idx_l0_active_minus1 >= CODEC_MAX_NUM_REF_FIELD || slcParams->num_ref_idx_l1_active_minus1 >= CODEC_MAX_NUM_REF_FIELD)
+    {
+        ENCODE_ASSERTMESSAGE("Invalid slice parameters.");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
     for (uint32_t sliceCount = 0; sliceCount < m_basicFeature->m_numSlices; sliceCount++)
     {
         if (m_pictureCodingType != I_TYPE)
@@ -265,6 +271,11 @@ MOS_STATUS AvcReferenceFrames::UpdateSlice()
             {
                 for (uint8_t i = 0; i < (slcParams->num_ref_idx_l0_active_minus1 + 1); i++)
                 {
+                    if (slcParams->RefPicList[0][i].FrameIdx >= CODEC_AVC_MAX_NUM_REF_FRAME)
+                    {
+                        ENCODE_ASSERTMESSAGE("Invalid slice parameters.");
+                        return MOS_STATUS_INVALID_PARAMETER;
+                    }
                     auto index = m_picIdx[slcParams->RefPicList[0][i].FrameIdx].ucPicIdx;
                     if (m_refList[index]->ucFrameId < hwInvalidFrameId)
                     {
@@ -284,7 +295,12 @@ MOS_STATUS AvcReferenceFrames::UpdateSlice()
             if (m_pictureCodingType == B_TYPE)
             {
                 for (uint8_t i = 0; i < (slcParams->num_ref_idx_l1_active_minus1 + 1); i++)
-                {
+                {                
+                    if (slcParams->RefPicList[1][i].FrameIdx >= CODEC_AVC_MAX_NUM_REF_FRAME)
+                    {
+                        ENCODE_ASSERTMESSAGE("Invalid slice parameters.");
+                        return MOS_STATUS_INVALID_PARAMETER;
+                    }
                     auto index = m_picIdx[slcParams->RefPicList[1][i].FrameIdx].ucPicIdx;
                     if (m_refList[index]->ucFrameId < hwInvalidFrameId)
                     {
@@ -548,17 +564,32 @@ MHW_SETPAR_DECL_SRC(VDENC_AVC_IMG_STATE, AvcReferenceFrames)
 
         MHW_CHK_STATUS_RETURN(slcParams->num_ref_idx_l0_active_minus1 > 2);
         uint8_t fwdRefIdx[3] = {0xf, 0xf, 0xf};
+        uint8_t fwdRefFieldType[3] = {0, 0, 0};
         for (auto i = 0; i < slcParams->num_ref_idx_l0_active_minus1 + 1; i++)
         {
             auto id = slcParams->RefPicList[LIST_0][i].FrameIdx;
             id = m_picIdx[id].ucPicIdx;
             fwdRefIdx[i] = m_refList[id]->ucFrameId;
-            refPoc[0][i] = (uint8_t)m_refList[id]->iFieldOrderCnt[0];
+
+            if (slcParams->RefPicList[LIST_0][i].PicFlags == PICTURE_TOP_FIELD) {
+                refPoc[0][i] = (uint8_t)m_refList[id]->iFieldOrderCnt[0];
+                fwdRefFieldType[i] = 0;
+            } else if (slcParams->RefPicList[LIST_0][i].PicFlags == PICTURE_BOTTOM_FIELD) {
+                refPoc[0][i] = (uint8_t)m_refList[id]->iFieldOrderCnt[1];
+                fwdRefFieldType[i] = 1;
+            } else {
+                refPoc[0][i] = (uint8_t)m_refList[id]->iFieldOrderCnt[0];
+                fwdRefFieldType[i] = 0;
+            }
         }
         params.fwdRefIdx0ReferencePicture = fwdRefIdx[0];
         params.fwdRefIdx1ReferencePicture = fwdRefIdx[1];
         params.fwdRefIdx2ReferencePicture = fwdRefIdx[2];
 
+        params.fwdRefIdx0FieldType = fwdRefFieldType[0];
+        params.fwdRefIdx1FieldType = fwdRefFieldType[1];
+        params.fwdRefIdx2FieldType = fwdRefFieldType[2];
+
         if (picParams->CodingType == B_TYPE)
         {
             auto id = slcParams->RefPicList[LIST_1][0].FrameIdx;
@@ -569,7 +600,17 @@ MHW_SETPAR_DECL_SRC(VDENC_AVC_IMG_STATE, AvcReferenceFrames)
             }             
             id = m_picIdx[id].ucPicIdx;
             params.bwdRefIdx0ReferencePicture = m_refList[id]->ucFrameId;
-            refPoc[1][0] = (uint8_t)m_refList[id]->iFieldOrderCnt[0];
+
+            if (slcParams->RefPicList[LIST_1][0].PicFlags == PICTURE_TOP_FIELD) {
+                refPoc[1][0] = (uint8_t)m_refList[id]->iFieldOrderCnt[0];
+                params.bwdRefIdx0FieldType = 0;
+            } else if (slcParams->RefPicList[LIST_1][0].PicFlags == PICTURE_BOTTOM_FIELD) {
+                refPoc[1][0] = (uint8_t)m_refList[id]->iFieldOrderCnt[1];
+                params.bwdRefIdx0FieldType = 1;
+            } else {
+                refPoc[1][0] = (uint8_t)m_refList[id]->iFieldOrderCnt[0];
+                params.bwdRefIdx0FieldType = 0;
+            }
         }
     }
 
