@@ -34,15 +34,15 @@ namespace encode
     HevcVdencScc::HevcVdencScc(
         MediaFeatureManager *featureManager,
         EncodeAllocator *allocator,
-        CodechalHwInterface *hwInterface,
+        CodechalHwInterfaceNext *hwInterface,
         void *constSettings) :
         MediaFeature(constSettings, hwInterface ? hwInterface->GetOsInterface() : nullptr)
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
         auto encFeatureManager = dynamic_cast<EncodeHevcVdencFeatureManager *>(featureManager);
         ENCODE_CHK_NULL_NO_STATUS_RETURN(encFeatureManager);
         ENCODE_CHK_NULL_NO_STATUS_RETURN(hwInterface);
-        CODECHAL_HW_ASSERT(hwInterface->GetOsInterface());
+        CODEC_HW_ASSERT(hwInterface->GetOsInterface());
         m_osInterface = hwInterface->GetOsInterface();
 
         m_basicFeature = dynamic_cast<EncodeBasicFeature *>(encFeatureManager->GetFeature(FeatureIDs::basicFeature));
@@ -59,7 +59,7 @@ namespace encode
 
     MOS_STATUS HevcVdencScc::Init(void *settings)
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
 
         CodechalSetting* codecSettings = (CodechalSetting*)settings;
         m_enableSCC = codecSettings->isSCCEnabled;
@@ -83,7 +83,7 @@ namespace encode
 
     MOS_STATUS HevcVdencScc::Update(void *params)
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
 
         auto hevcFeature = dynamic_cast<HevcBasicFeature *>(m_basicFeature);
         ENCODE_CHK_NULL_RETURN(hevcFeature);
@@ -107,7 +107,7 @@ namespace encode
 
     MOS_STATUS HevcVdencScc::AllocateEncResources()
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
 
         if (!m_enableSCC)
         {
@@ -174,13 +174,13 @@ namespace encode
             return eStatus;
         }
 
-        if (m_mmcEnabled)
+        if (m_mmcEnabled && IsCompressFlagNeeded())
         {
             allocParamsForBuffer2D.bIsCompressible = true;
             allocParamsForBuffer2D.CompressionMode = MOS_MMC_MC;
         }
         allocParamsForBuffer2D.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
-        CODECHAL_ENCODE_CHK_STATUS_MESSAGE_RETURN(m_osInterface->pfnAllocateResource(
+        ENCODE_CHK_STATUS_MESSAGE_RETURN(m_osInterface->pfnAllocateResource(
                     m_osInterface,
                     &allocParamsForBuffer2D,
                     &m_vdencRecNotFilteredBuffer),
@@ -193,7 +193,7 @@ namespace encode
 
     MOS_STATUS HevcVdencScc::FreeEncResources()
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
         ENCODE_CHK_NULL_RETURN(m_osInterface);
         m_osInterface->pfnFreeResource(m_osInterface, &m_vdencRecNotFilteredBuffer);
         return MOS_STATUS_SUCCESS;
@@ -201,11 +201,11 @@ namespace encode
 
     MOS_STATUS HevcVdencScc::SetHucBrcUpdateDmem(void* hucVdencBrcUpdateDmem)
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
 
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
         VdencHevcHucBrcUpdateDmem *phucVdencBrcUpdateDmem = (VdencHevcHucBrcUpdateDmem *)hucVdencBrcUpdateDmem;
-        CODECHAL_ENCODE_CHK_NULL_RETURN(hucVdencBrcUpdateDmem);
+        ENCODE_CHK_NULL_RETURN(hucVdencBrcUpdateDmem);
         // SCC is in conflict with PAK only pass
         if (m_enableSCC)
         {
@@ -216,17 +216,9 @@ namespace encode
         return eStatus;
     }
 
-    MOS_STATUS HevcVdencScc::SetVdencWalkerStateParams(MHW_VDBOX_VDENC_WALKER_STATE_PARAMS_G12 &vdencWalkerStateParams)
-    {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
-
-        vdencWalkerStateParams.IBCControl = m_enableLBCOnly ? 1 : 3;
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS HevcVdencScc::SetRecNotFilteredID(unsigned char &slotForRecNotFiltered)
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
         slotForRecNotFiltered = m_slotForRecNotFiltered;
         return MOS_STATUS_SUCCESS;
     }
@@ -399,7 +391,7 @@ namespace encode
 
     MHW_SETPAR_DECL_SRC(HCP_REF_IDX_STATE, HevcVdencScc)
     {
-        CODECHAL_ENCODE_FUNCTION_ENTER;
+        ENCODE_FUNC_CALL();
 
         auto hevcFeature = dynamic_cast<HevcBasicFeature *>(m_basicFeature);
         ENCODE_CHK_NULL_RETURN(hevcFeature);
@@ -412,7 +404,7 @@ namespace encode
             params.numRefIdxLRefpiclistnumActiveMinus1++;
             ucNumRefForList = params.numRefIdxLRefpiclistnumActiveMinus1;
 
-            if ((hevcFeature->m_hevcPicParams->CodingType == I_TYPE) && (hevcFeature->m_hevcSliceParams->slice_type == MhwVdboxHcpInterface::hevcSliceP))
+            if ((hevcFeature->m_hevcPicParams->CodingType == I_TYPE) && (hevcFeature->m_hevcSliceParams->slice_type == mhw::vdbox::hcp::hevcSliceP))
             {
                 ucNumRefForList = 0;
                 params.numRefIdxLRefpiclistnumActiveMinus1 = 0;
